pub struct TableChangeLogManager {
cache: Cache<CacheKey, Shared<Pin<Box<dyn Future<Output = HummockResult<TableChangeLogs>> + Send>>>>,
hummock_meta_client: Arc<dyn HummockMetaClient>,
}Expand description
A naive cache to reduce number of RPC sent to meta node.
Fields
cache: Cache<CacheKey, Shared<Pin<Box<dyn Future<Output = HummockResult<TableChangeLogs>> + Send>>>>hummock_meta_client: Arc<dyn HummockMetaClient>Implementations
Sourceimpl TableChangeLogManager
impl TableChangeLogManager
pub fn new( capacity: u64, hummock_meta_client: Arc<dyn HummockMetaClient>, ) -> Self
async fn get_or_insert( &self, table_id: TableId, epoch_range: (u64, u64), include_epoch_only: bool, limit: Option<u32>, fetch: impl Future<Output = HummockResult<TableChangeLogs>> + Send + 'static, ) -> HummockResult<TableChangeLogs>
Sourcepub async fn fetch_table_change_logs(
&self,
table_id: TableId,
epoch_range: (u64, u64),
include_epoch_only: bool,
limit: Option<u32>,
) -> HummockResult<TableChangeLogs>
pub async fn fetch_table_change_logs( &self, table_id: TableId, epoch_range: (u64, u64), include_epoch_only: bool, limit: Option<u32>, ) -> HummockResult<TableChangeLogs>
Fetches table change logs for the given table_id and epoch_range.
- If the end value of
epoch_rangeis notu64::MAX, attempts to retrieve logs from the cache; if not cached, fetches via an RPC to the meta node and stores the result in the cache. - If the end value of
epoch_rangeisu64::MAX, always fetches table change logs directly from the meta node (bypassing the cache).
Both the start and end values of epoch_range are inclusive.
IMPORTANT: The caller must guarantee that the current max committed epoch is at least as large as the end of the provided epoch_range, if it’s not u64::MAX.
Otherwise, the cache may serve outdated results: as new epochs are committed beyond the current maximum, subsequent RPC calls for the same epoch_range
could retrieve different or additional change logs that were not present in the previously cached result. For example, if you request logs for
epoch_range = (1, N) when the current max committed epoch is M < N, committing epochs M+1 through N would make the cache inconsistent with reality;
future fetches for (1, N) could return new or updated information absent from the previous cache entry.